==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/integrationspaces/kotlin/inputs/GetApplicationBusinessProcessDevelopmentArtifactPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.integrationspaces.kotlin.inputs

import com.pulumi.azurenative.integrationspaces.inputs.GetApplicationBusinessProcessDevelopmentArtifactPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property applicationName The name of the Application
 * @property name The name of the business process development artifact.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property spaceName The name of the space
 */
public data class GetApplicationBusinessProcessDevelopmentArtifactPlainArgs(
    public val applicationName: String,
    public val name: String,
    public val resourceGroupName: String,
    public val spaceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.integrationspaces.inputs.GetApplicationBusinessProcessDevelopmentArtifactPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.integrationspaces.inputs.GetApplicationBusinessProcessDevelopmentArtifactPlainArgs =
        com.pulumi.azurenative.integrationspaces.inputs.GetApplicationBusinessProcessDevelopmentArtifactPlainArgs.builder()
            .applicationName(applicationName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .spaceName(spaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetApplicationBusinessProcessDevelopmentArtifactPlainArgs].
 */
@PulumiTagMarker
public class GetApplicationBusinessProcessDevelopmentArtifactPlainArgsBuilder internal constructor() {
    private var applicationName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    private var spaceName: String? = null

    /**
     * @param value The name of the Application
     */
    @JvmName("gyjrdhwkbclhxrqo")
    public suspend fun applicationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.applicationName = mapped
    }

    /**
     * @param value The name of the business process development artifact.
     */
    @JvmName("eukbvyfvdvikmrtr")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("qrgwsoaselvjlico")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the space
     */
    @JvmName("rmvesrswjivtbubl")
    public suspend fun spaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.spaceName = mapped
    }

    internal fun build(): GetApplicationBusinessProcessDevelopmentArtifactPlainArgs =
        GetApplicationBusinessProcessDevelopmentArtifactPlainArgs(
            applicationName = applicationName ?: throw PulumiNullFieldException("applicationName"),
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            spaceName = spaceName ?: throw PulumiNullFieldException("spaceName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/integrationspaces/kotlin/inputs/GetApplicationBusinessProcessDevelopmentArtifactPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.integrationspaces.kotlin.inputs

import com.pulumi.azurenative.integrationspaces.inputs.GetApplicationBusinessProcessDevelopmentArtifactPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property applicationName The name of the Application
 * @property name The name of the business process development artifact.
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property spaceName The name of the space
 */
public data class GetApplicationBusinessProcessDevelopmentArtifactPlainArgs(
    public val applicationName: String,
    public val name: String,
    public val resourceGroupName: String,
    public val spaceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.integrationspaces.inputs.GetApplicationBusinessProcessDevelopmentArtifactPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.integrationspaces.inputs.GetApplicationBusinessProcessDevelopmentArtifactPlainArgs =
        com.pulumi.azurenative.integrationspaces.inputs.GetApplicationBusinessProcessDevelopmentArtifactPlainArgs.builder()
            .applicationName(applicationName.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .spaceName(spaceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetApplicationBusinessProcessDevelopmentArtifactPlainArgs].
 */
@PulumiTagMarker
public class GetApplicationBusinessProcessDevelopmentArtifactPlainArgsBuilder internal constructor() {
    private var applicationName: String? = null

    private var name: String? = null

    private var resourceGroupName: String? = null

    private var spaceName: String? = null

    /**
     * @param value The name of the Application
     */
    @JvmName("ehmhqokajxbfxqyj")
    public suspend fun applicationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.applicationName = mapped
    }

    /**
     * @param value The name of the business process development artifact.
     */
    @JvmName("hygxmsyxvrfwsahj")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("yhyoljqkoraswngq")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the space
     */
    @JvmName("synyeysxiiofnuno")
    public suspend fun spaceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.spaceName = mapped
    }

    internal fun build(): GetApplicationBusinessProcessDevelopmentArtifactPlainArgs =
        GetApplicationBusinessProcessDevelopmentArtifactPlainArgs(
            applicationName = applicationName ?: throw PulumiNullFieldException("applicationName"),
            name = name ?: throw PulumiNullFieldException("name"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            spaceName = spaceName ?: throw PulumiNullFieldException("spaceName"),
        )
}
